# tw_vid

A simple library for extracting and corrupting frames from videos.

## Installation

`pip install tw_vid`

> [!NOTE]
> This has only been tested on Python 3.11 and 3.12.

## Usage

See [example.py](https://github.com/Martyrdome/12Vid/blob/main/example.py).
